inspire\_info package
=====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   inspire_info.scripts

Submodules
----------

inspire\_info.Author module
---------------------------

.. automodule:: inspire_info.Author
   :members:
   :undoc-members:
   :show-inheritance:

inspire\_info.InspireInfo module
--------------------------------

.. automodule:: inspire_info.InspireInfo
   :members:
   :undoc-members:
   :show-inheritance:

inspire\_info.LatexCreator module
---------------------------------

.. automodule:: inspire_info.LatexCreator
   :members:
   :undoc-members:
   :show-inheritance:

inspire\_info.Publication module
--------------------------------

.. automodule:: inspire_info.Publication
   :members:
   :undoc-members:
   :show-inheritance:

inspire\_info.cli module
------------------------

.. automodule:: inspire_info.cli
   :members:
   :undoc-members:
   :show-inheritance:

inspire\_info.myutils module
----------------------------

.. automodule:: inspire_info.myutils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: inspire_info
   :members:
   :undoc-members:
   :show-inheritance:
